==> openshift-model-operator-5.7.3-sources.jar: io/fabric8/openshift/api/model/operator/v1/StaticIPAMRoutesBuilder.java <==
package io.fabric8.openshift.api.model.operator.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class StaticIPAMRoutesBuilder extends io.fabric8.openshift.api.model.operator.v1.StaticIPAMRoutesFluentImpl<io.fabric8.openshift.api.model.operator.v1.StaticIPAMRoutesBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.operator.v1.StaticIPAMRoutes,io.fabric8.openshift.api.model.operator.v1.StaticIPAMRoutesBuilder>{
  public StaticIPAMRoutesBuilder() {
    this(false);
  }
  public StaticIPAMRoutesBuilder(java.lang.Boolean validationEnabled) {
    this(new StaticIPAMRoutes(), validationEnabled);
  }
  public StaticIPAMRoutesBuilder(io.fabric8.openshift.api.model.operator.v1.StaticIPAMRoutesFluent<?> fluent) {
    this(fluent, false);
  }
  public StaticIPAMRoutesBuilder(io.fabric8.openshift.api.model.operator.v1.StaticIPAMRoutesFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new StaticIPAMRoutes(), validationEnabled);
  }
  public StaticIPAMRoutesBuilder(io.fabric8.openshift.api.model.operator.v1.StaticIPAMRoutesFluent<?> fluent,io.fabric8.openshift.api.model.operator.v1.StaticIPAMRoutes instance) {
    this(fluent, instance, false);
  }
  public StaticIPAMRoutesBuilder(io.fabric8.openshift.api.model.operator.v1.StaticIPAMRoutesFluent<?> fluent,io.fabric8.openshift.api.model.operator.v1.StaticIPAMRoutes instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withDestination(instance.getDestination()); 
    fluent.withGateway(instance.getGateway()); 
    this.validationEnabled = validationEnabled; 
  }
  public StaticIPAMRoutesBuilder(io.fabric8.openshift.api.model.operator.v1.StaticIPAMRoutes instance) {
    this(instance,false);
  }
  public StaticIPAMRoutesBuilder(io.fabric8.openshift.api.model.operator.v1.StaticIPAMRoutes instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withDestination(instance.getDestination()); 
    this.withGateway(instance.getGateway()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.operator.v1.StaticIPAMRoutesFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.operator.v1.StaticIPAMRoutes build() {
    StaticIPAMRoutes buildable = new StaticIPAMRoutes(fluent.getDestination(),fluent.getGateway());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    StaticIPAMRoutesBuilder that = (StaticIPAMRoutesBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-operator-5.11.1-sources.jar: io/fabric8/openshift/api/model/operator/v1/StaticIPAMRoutesBuilder.java <==
package io.fabric8.openshift.api.model.operator.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class StaticIPAMRoutesBuilder extends io.fabric8.openshift.api.model.operator.v1.StaticIPAMRoutesFluentImpl<io.fabric8.openshift.api.model.operator.v1.StaticIPAMRoutesBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.operator.v1.StaticIPAMRoutes,io.fabric8.openshift.api.model.operator.v1.StaticIPAMRoutesBuilder>{
  public StaticIPAMRoutesBuilder() {
    this(false);
  }
  public StaticIPAMRoutesBuilder(java.lang.Boolean validationEnabled) {
    this(new StaticIPAMRoutes(), validationEnabled);
  }
  public StaticIPAMRoutesBuilder(io.fabric8.openshift.api.model.operator.v1.StaticIPAMRoutesFluent<?> fluent) {
    this(fluent, false);
  }
  public StaticIPAMRoutesBuilder(io.fabric8.openshift.api.model.operator.v1.StaticIPAMRoutesFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new StaticIPAMRoutes(), validationEnabled);
  }
  public StaticIPAMRoutesBuilder(io.fabric8.openshift.api.model.operator.v1.StaticIPAMRoutesFluent<?> fluent,io.fabric8.openshift.api.model.operator.v1.StaticIPAMRoutes instance) {
    this(fluent, instance, false);
  }
  public StaticIPAMRoutesBuilder(io.fabric8.openshift.api.model.operator.v1.StaticIPAMRoutesFluent<?> fluent,io.fabric8.openshift.api.model.operator.v1.StaticIPAMRoutes instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withDestination(instance.getDestination()); 
    fluent.withGateway(instance.getGateway()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public StaticIPAMRoutesBuilder(io.fabric8.openshift.api.model.operator.v1.StaticIPAMRoutes instance) {
    this(instance,false);
  }
  public StaticIPAMRoutesBuilder(io.fabric8.openshift.api.model.operator.v1.StaticIPAMRoutes instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withDestination(instance.getDestination()); 
    this.withGateway(instance.getGateway()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.operator.v1.StaticIPAMRoutesFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.operator.v1.StaticIPAMRoutes build() {
    StaticIPAMRoutes buildable = new StaticIPAMRoutes(fluent.getDestination(),fluent.getGateway());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    StaticIPAMRoutesBuilder that = (StaticIPAMRoutesBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
